import { Component, ElementRef, EventEmitter, Input, Output, Renderer2 } from '@angular/core';
import { BsModalDismissReason } from './bs-modal-dismiss-reason';
var BsModalWindowComponent = (function () {
    function BsModalWindowComponent(_elRef, _renderer) {
        this._elRef = _elRef;
        this._renderer = _renderer;
        this.backdrop = true;
        this.keyboard = true;
        this.dismissEvent = new EventEmitter();
    }
    BsModalWindowComponent.prototype.ngOnInit = function () {
        this._elWithFocus = document.activeElement;
        // this._renderer.setElementClass(document.body, 'modal-open', true);
        this._renderer.addClass(document.body, 'modal-open');
    };
    BsModalWindowComponent.prototype.ngAfterViewInit = function () {
        if (!this._elRef.nativeElement.contains(document.activeElement)) {
            // this._renderer.invokeElementMethod(this._elRef.nativeElement, 'focus', []);
            this._elRef.nativeElement.focus();
        }
    };
    BsModalWindowComponent.prototype.ngOnDestroy = function () {
        if (this._elWithFocus && document.body.contains(this._elWithFocus)) {
            // this._renderer.invokeElementMethod(this._elWithFocus, 'focus', []);
            this._elWithFocus.focus();
        }
        else {
            // this._renderer.invokeElementMethod(document.body, 'focus', []);
            document.body.focus();
        }
        this._elWithFocus = null;
        // this._renderer.setElementClass(document.body, 'modal-open', false);
        this._renderer.removeClass(document.body, 'modal-open');
    };
    BsModalWindowComponent.prototype.backdropClick = function ($event) {
        if (this.backdrop === true && this._elRef.nativeElement === $event.target) {
            this.dismiss(BsModalDismissReason.BACKDROP_CLICK);
        }
    };
    BsModalWindowComponent.prototype.escKey = function ($event) {
        if (this.keyboard && !$event.defaultPrevented) {
            this.dismiss(BsModalDismissReason.ESC);
        }
    };
    BsModalWindowComponent.prototype.dismiss = function (reason) { this.dismissEvent.emit(reason); };
    return BsModalWindowComponent;
}());
export { BsModalWindowComponent };
BsModalWindowComponent.decorators = [
    { type: Component, args: [{
                selector: 'bs-modal-window',
                host: {
                    '[class]': '"modal fade show" + (windowClass ? " " + windowClass : "")',
                    'role': 'dialog',
                    'tabindex': '-1',
                    'style': 'display: block;',
                    '(keyup.esc)': 'escKey($event)',
                    '(click)': 'backdropClick($event)'
                },
                template: "\n        <div [class]=\"'modal-dialog' + (size ? ' modal-' + size : '')\" role=\"document\">\n            <div class=\"modal-content\"><ng-content></ng-content></div>\n        </div>\n    "
            },] },
];
/** @nocollapse */
BsModalWindowComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
]; };
BsModalWindowComponent.propDecorators = {
    'backdrop': [{ type: Input },],
    'keyboard': [{ type: Input },],
    'size': [{ type: Input },],
    'windowClass': [{ type: Input },],
    'dismissEvent': [{ type: Output, args: ['dismiss',] },],
};
//# sourceMappingURL=bs-modal-window.js.map